@@ -10,7 +10,7 @@ PyPI: https://pypi.org/project/pyspecan/
 This is intended to be used as a callable module (or a script), but can be used as a library
 """
 
-__version__ = "0.3.0"
+__version__ = "0.3.4"
 __author__ = "Anonoei <to+dev@an0.cx>"
 
 from . import _internal
@@ -20,6 +20,6 @@ from . import err
 from . import obj
 from . import utils
 
-from .model.model import Model
+# from .model.base import Model
 
 from .specan import SpecAn
