@@ -16,6 +16,13 @@ class Mode(Enum):
             arr.append(inst.name)
         return arr
 
+    @classmethod
+    def get(cls, option: str):
+        for inst in cls:
+            if inst.name == option:
+                return inst
+        return cls.NONE
+
 class View(Enum):
     """Specan views"""
     NONE = (("none",), None)
@@ -28,7 +35,7 @@ class View(Enum):
         return self.value[1]
 
     @classmethod
-    def get_view(cls, option: str):
+    def get(cls, option: str):
         """return view instance"""
         for inst in cls:
             if inst.name == option or option in inst.value[0]:
@@ -55,6 +62,10 @@ class config:
     SENTINEL = object()
     MODE: Mode = Mode.NONE
 
+    MON_MEM: bool = False
+    PROFILE: bool = False
+    PROFILE_PATH = [None, "pyspecan.prof"][1]
+
     def __new__(cls):
         if cls.__instance is None:
             cls.__instance = object.__new__(cls)
