@@ -29,7 +29,7 @@ def psd(samples, nfft=1024, overlap=0.8, Fs=1.0, vbw=None, win="blackman"):
         _psd = _psd**2 / (nfft*Fs)
         _psd = 10.0*np.log10(_psd)
         _psd = np.fft.fftshift(_psd)
-        if not vbw is None:
+        if vbw is not None:
             _psd = _vbw(_psd, vbw)
         out[:,i] = _psd
     return out
