@@ -1,10 +1,6 @@
 """Initialize View base class"""
 class View:
     """Parent view class"""
-    __slots__ = ("view",)
-    def __init__(self, view):
-        self.view = view
-
     def mainloop(self):
         """Initialize the view"""
 
